abacusai.hosted_app_file_read — AbacusAI documentation

# abacusai.hosted_app_file_read

## Classes

`HostedAppFileRead` | Result of reading file content from a hosted app container.

## Module Contents

class abacusai.hosted_app_file_read.HostedAppFileRead(client, content=None, start=None, end=None, retcode=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Result of reading file content from a hosted app container.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - content (str) – The contents of the file or a portion of it.

    - start (int) – If present, the starting position of the read.

    - end (int) – If present, the last position in the file returned in this read.

    - retcode (int) – If the read is associated with a log the return code of the command.

  content = None
  start = None
  end = None
  retcode = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict